#[repr(C)]pub struct blaze_symbolizer_dispatch {
pub dispatch_cb: unsafe extern "C" fn(maps_file: *const c_char, symbolic_path: *const c_char, ctx: *mut c_void) -> *mut c_char,
pub ctx: *mut c_void,
}Expand description
Configuration for custom process member dispatch.
When provided to blaze_symbolizer_opts via
process_dispatch, the
callback is invoked for each process member that has a file path during
process symbolization. It allows the caller to provide an alternative
ELF file path for symbolization. For example, the path may be fetched
via debuginfod.
The callback receives the /proc/<pid>/map_files/... path and the
symbolic path from /proc/<pid>/maps, along with the user-provided
context pointer (ctx).
The callback should return one of:
- A
malloc’d path string to an alternative ELF file to use for symbolization. The library willfreethis string after use. NULLto use the default symbolization behavior for this member.
Fields
dispatch_cb: unsafe extern "C" fn(maps_file: *const c_char, symbolic_path: *const c_char, ctx: *mut c_void) -> *mut c_charThe dispatch callback function. Must not be NULL.
ctx: *mut c_voidOpaque context pointer passed to dispatch_cb.